"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserController = void 0;
const openapi = require("@nestjs/swagger");
const common_1 = require("@nestjs/common");
const platform_express_1 = require("@nestjs/platform-express");
const swagger_1 = require("@nestjs/swagger");
const user_schema_1 = require("../schemas/user.schema");
const user_service_1 = require("../services/user.service");
let UserController = class UserController {
    constructor(userService) {
        this.userService = userService;
    }
    async findAll() {
        return this.userService.findAll();
    }
    async findByRoleAndStatus(role, status) {
        return this.userService.findByRoleAndStatus(role, status);
    }
    async getById(id) {
        return this.userService.getById(id);
    }
    async create(image, user) {
        var _a;
        const existingUser = await this.userService.findUser(user.phone, user.username);
        if (existingUser) {
            throw new common_1.HttpException('User already exists!', common_1.HttpStatus.FORBIDDEN);
        }
        if (image && user.image) {
            user.image = (_a = image === null || image === void 0 ? void 0 : image.buffer) === null || _a === void 0 ? void 0 : _a.toString("base64");
        }
        return this.userService.create(user);
    }
    async edit(userId, image, updatedUser) {
        var _a;
        try {
            if (updatedUser.image &&
                !updatedUser.image.startsWith("https")) {
                if (image && updatedUser.image) {
                    updatedUser.image = (_a = image === null || image === void 0 ? void 0 : image.buffer) === null || _a === void 0 ? void 0 : _a.toString("base64");
                }
            }
            return this.userService.edit(userId, updatedUser);
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException(`User with ID ${userId} not found`, common_1.HttpStatus.NOT_FOUND);
            }
            throw error;
        }
    }
    async delete(userId) {
        try {
            await this.userService.delete(userId);
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException(`User with ID ${userId} not found`, common_1.HttpStatus.NOT_FOUND);
            }
            throw error;
        }
    }
    async activateUser(userId, status) {
        try {
            return this.userService.activateUser(userId, status);
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException(`User with ID ${userId} not found`, common_1.HttpStatus.NOT_FOUND);
            }
            throw error;
        }
    }
    async login({ email, password, phone }, req) {
        const macAddress = req.headers['device-id'] || req.headers['x-device-id'] || '';
        try {
            return await this.userService.loginUser(email, password, phone);
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException("Invalid credentials", common_1.HttpStatus.UNAUTHORIZED);
            }
            throw error;
        }
    }
    async refreshAccessToken({ refreshToken }) {
        try {
            const accessToken = await this.userService.refreshAccessToken(refreshToken);
            return { accessToken };
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException("Invalid refresh token", common_1.HttpStatus.UNAUTHORIZED);
            }
            throw error;
        }
    }
    async getMe(id) {
        return this.userService.getMe(id);
    }
    async logout({ refreshToken }) {
        await this.userService.logoutUser(refreshToken);
    }
    async resetPassword(userId, password) {
        try {
            return this.userService.resetPassword(userId, password);
        }
        catch (error) {
            if (error instanceof common_1.NotFoundException) {
                throw new common_1.HttpException(`User with ID ${userId} not found`, common_1.HttpStatus.NOT_FOUND);
            }
            throw error;
        }
    }
};
__decorate([
    (0, common_1.Get)("get-all"),
    openapi.ApiResponse({ status: 200, type: [require("../viewModel/user.dto").UserDTO] }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], UserController.prototype, "findAll", null);
__decorate([
    (0, common_1.Get)("get-by-role-and-status"),
    openapi.ApiResponse({ status: 200, type: [require("../schemas/user.schema").User] }),
    __param(0, (0, common_1.Query)("role")),
    __param(1, (0, common_1.Query)("status")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Boolean]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "findByRoleAndStatus", null);
__decorate([
    (0, common_1.Get)("get-by-id"),
    openapi.ApiResponse({ status: 200, type: require("../viewModel/user.dto").UserDTO }),
    __param(0, (0, common_1.Query)("id")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "getById", null);
__decorate([
    (0, common_1.Post)("create"),
    (0, common_1.UseInterceptors)((0, platform_express_1.FileInterceptor)("image")),
    openapi.ApiResponse({ status: 201, type: require("../schemas/user.schema").User }),
    __param(0, (0, common_1.UploadedFile)()),
    __param(1, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, user_schema_1.User]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "create", null);
__decorate([
    (0, common_1.Put)('edit/:id'),
    (0, common_1.UseInterceptors)((0, platform_express_1.FileInterceptor)("image")),
    openapi.ApiResponse({ status: 200, type: require("../schemas/user.schema").User }),
    __param(0, (0, common_1.Param)('id')),
    __param(1, (0, common_1.UploadedFile)()),
    __param(2, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object, user_schema_1.User]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "edit", null);
__decorate([
    (0, common_1.Delete)('delete/:id'),
    openapi.ApiResponse({ status: 200 }),
    __param(0, (0, common_1.Param)('id')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "delete", null);
__decorate([
    (0, common_1.Put)('activate/:id'),
    openapi.ApiResponse({ status: 200, type: require("../schemas/user.schema").User }),
    __param(0, (0, common_1.Param)('id')),
    __param(1, (0, common_1.Body)('status')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Boolean]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "activateUser", null);
__decorate([
    (0, common_1.Post)("login"),
    openapi.ApiResponse({ status: 201 }),
    __param(0, (0, common_1.Body)()),
    __param(1, (0, common_1.Req)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "login", null);
__decorate([
    (0, common_1.Post)("refresh-token"),
    openapi.ApiResponse({ status: 201 }),
    __param(0, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "refreshAccessToken", null);
__decorate([
    (0, common_1.Get)("get-me"),
    openapi.ApiResponse({ status: 200, type: require("../schemas/user.schema").User }),
    __param(0, (0, common_1.Query)("id")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "getMe", null);
__decorate([
    (0, common_1.Post)("logout"),
    openapi.ApiResponse({ status: 201 }),
    __param(0, (0, common_1.Body)()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "logout", null);
__decorate([
    (0, common_1.Put)('reset-password/:id'),
    openapi.ApiResponse({ status: 200, type: require("../schemas/user.schema").User }),
    __param(0, (0, common_1.Param)('id')),
    __param(1, (0, common_1.Body)('password')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String]),
    __metadata("design:returntype", Promise)
], UserController.prototype, "resetPassword", null);
UserController = __decorate([
    (0, swagger_1.ApiTags)("Users"),
    (0, common_1.Controller)("users"),
    __metadata("design:paramtypes", [user_service_1.UserService])
], UserController);
exports.UserController = UserController;
//# sourceMappingURL=user.controller.js.map